<?php

return[
    'project_modules' => [
        'pages' => [
            'inline_editor' => [
                'label'        => 'Редактор содержимого (Inline editor)',
                'file'         => __DIR__ . '/../docs/inlineeditor_usr.md',
                'position'     => 40,
                'acl_resource' => 'inlineeditor',
                'acl_action'   => 'edit_inlineeditor',
            ],
        ]
    ],
    'developer_docs' => [
        'pages' => [
            'inlineeditor_dev' => [
                'label'    => 'Редактор содержимого (Inline editor)',
                'file'     => __DIR__ . '/../docs/inlineeditor_dev.md',
                'position' => 60,
                'acl_resource' => 'inlineeditor',
                'acl_action'   => 'edit_inlineeditor',
            ]
        ]
    ]
];
